import { Component, EventEmitter, Output } from '@angular/core';
import { ModalController, NavParams, ViewController } from 'ionic-angular';
import moment from 'moment/src/moment';

function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function __metadata(k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
}

var DatePicker = DatePicker_1 = (function () {
    function DatePicker(modalCtrl, viewCtrl, params) {
        this.modalCtrl = modalCtrl;
        this.viewCtrl = viewCtrl;
        this.onDateSelected = new EventEmitter();
        this.onCancelled = new EventEmitter();
        this.daysGroupedByWeek = [];
        this.currentMoment = moment();
        this.datePickerOption = params && params.data ? params.data : this.datePickerOption;
        this.renderCalender();
    }
    DatePicker.prototype.renderCalender = function () {
        this.daysOfMonth = this.generateDaysOfMonth(this.currentMoment.year(), this.currentMoment.month() + 1, this.currentMoment.date());
        this.daysGroupedByWeek = this.groupByWeek(this.daysOfMonth);
        this.setTodayAsDefaultSelectedDate();
    };
    DatePicker.prototype.generateDaysOfMonth = function (year, month, day) {
        var calendarMonth = moment(year + "-" + month + "-" + day, "YYYY-MM-DD");
        var startOfMonth = calendarMonth.clone().startOf("month").day("sunday");
        var endOfMonth = calendarMonth.clone().endOf("month").day("saturday");
        var totalDays = endOfMonth.diff(startOfMonth, "days") + 1;
        var calendarDays = [];
        for (var i = 0; i < totalDays; i++) {
            var immunableStartOfMonth = startOfMonth.clone();
            var dateItem = {
                isSelected: false,
                momentDate: immunableStartOfMonth.add(i, "day"),
                isEnabled: true
            };
            dateItem.isEnabled = this.isBelongToThisMonth(immunableStartOfMonth, month) &&
                this.startingFrom(dateItem.momentDate) && this.endingAt(dateItem.momentDate);
            calendarDays.push(dateItem);
        }
        return calendarDays;
    };
    DatePicker.prototype.groupByWeek = function (daysOfMonth) {
        var groupedDaysOfMonth = new Array();
        daysOfMonth.forEach(function (item, index) {
            var groupIndex = Math.floor((index / 7));
            groupedDaysOfMonth[groupIndex] = groupedDaysOfMonth[groupIndex] || [];
            groupedDaysOfMonth[groupIndex].push(item);
        });
        return groupedDaysOfMonth;
    };
    DatePicker.prototype.selectDate = function (day) {
        if (!day.isEnabled)
            return;
        if (this.selectedDateItem && this.selectedDateItem.isSelected) {
            this.selectedDateItem.isSelected = false;
        }
        day.isSelected = true;
        this.selectedDateItem = day;
        this.currentMoment = day.momentDate.clone();
    };
    DatePicker.prototype.setTodayAsDefaultSelectedDate = function () {
        var today = moment().startOf("day");
        var foundDates = this.daysOfMonth
            .filter(function (item) { return today.isSame(item.momentDate.clone().startOf("day")); });
        if (foundDates && foundDates.length > 0) {
            this.selectedDateItem = foundDates[0];
            this.selectedDateItem.isSelected = true;
        }
    };
    DatePicker.prototype.isBelongToThisMonth = function (momentDate, month) {
        return momentDate.month() + 1 === month;
    };
    DatePicker.prototype.setMonthBack = function () {
        this.currentMoment.subtract(1, "month");
        this.renderCalender();
    };
    DatePicker.prototype.setMonthForward = function () {
        this.currentMoment.add(1, "month");
        this.renderCalender();
    };
    DatePicker.prototype.setYearBack = function () {
        this.currentMoment.subtract(1, "year");
        this.renderCalender();
    };
    DatePicker.prototype.setYearForward = function () {
        this.currentMoment.add(1, "year");
        this.renderCalender();
    };
    DatePicker.prototype.startingFrom = function (currentMomentDate) {
        if (!this.datePickerOption || !this.datePickerOption.minimumDate)
            return true;
        var startOfMinimumDay = this.datePickerOption.minimumDate.setHours(0);
        return currentMomentDate.startOf('day')
            .isSameOrAfter(moment(startOfMinimumDay).startOf('day'));
    };
    DatePicker.prototype.endingAt = function (endingMomentDate) {
        if (!this.datePickerOption || !this.datePickerOption.maximumDate)
            return true;
        var startOfMaximumDay = this.datePickerOption.maximumDate.setHours(0);
        return endingMomentDate.startOf('day')
            .isSameOrBefore(moment(startOfMaximumDay).startOf('day'));
    };
    DatePicker.prototype.confirmDateSelection = function () {
        this.viewCtrl.dismiss(this.selectedDateItem.momentDate.toDate());
    };
    DatePicker.prototype.cancel = function () {
        this.viewCtrl.dismiss();
    };
    DatePicker.prototype.showCalendar = function (datePickerOption) {
        var _this = this;
        this.calendarModal = this.modalCtrl.create(DatePicker_1, datePickerOption);
        this.calendarModal.onDidDismiss(function (data) {
            if (data) {
                _this.onDateSelected.emit(data);
            }
            else {
                _this.onCancelled.emit();
            }
        });
        this.calendarModal.present();
    };
    return DatePicker;
}());
__decorate([
    Output(),
    __metadata("design:type", typeof (_a = typeof EventEmitter !== "undefined" && EventEmitter) === "function" && _a || Object)
], DatePicker.prototype, "onDateSelected", void 0);
__decorate([
    Output(),
    __metadata("design:type", typeof (_b = typeof EventEmitter !== "undefined" && EventEmitter) === "function" && _b || Object)
], DatePicker.prototype, "onCancelled", void 0);
DatePicker = DatePicker_1 = __decorate([
    Component({
        selector: 'date-picker',
        template: "<div class=\"date-picker\">\n  <div class=\"layout-col horizontal-center layout-background\">\n    <div class=\"layout-col horizontal-center top-banner\">\n      <div class=\"dayofweek padding-5\">{{currentMoment.format('dddd')}}</div>\n      <div class=\"text-center padding-10\">\n        <div class=\"padding-5\">\n          <ion-icon class=\"arrow\" name=\"arrow-back\" (click)=\"setMonthBack()\"></ion-icon>\n          <span class=\"month padding-10\">{{currentMoment.format('MMM')}}</span>\n          <ion-icon class=\"arrow\" name=\"arrow-forward\" (click)=\"setMonthForward()\"></ion-icon>\n        </div>\n        <div class=\"day padding-5\">{{currentMoment.format('D')}}</div>\n        <div class=\"text-center padding-5\">\n          <ion-icon class=\"arrow\" name=\"arrow-back\" (click)=\"setYearBack()\"></ion-icon>\n          <span class=\"year padding-10\">{{currentMoment.format('YYYY')}}</span>\n          <ion-icon class=\"arrow\" name=\"arrow-forward\" (click)=\"setYearForward()\"></ion-icon>\n        </div>\n      </div>\n    </div>\n    <div class=\"month-year\">{{currentMoment.format('MMMM YYYY')}}</div>\n    <div class=\"calendar-item-container\">\n      <div class=\"layout-row day-item-header\">\n        <div class=\"day-item-header-item\">S</div>\n        <div class=\"day-item-header-item\">M</div>\n        <div class=\"day-item-header-item\">T</div>\n        <div class=\"day-item-header-item\">W</div>\n        <div class=\"day-item-header-item\">T</div>\n        <div class=\"day-item-header-item\">F</div>\n        <div class=\"day-item-header-item\">S</div>\n      </div>\n      <div class=\"layout-row day-container\" *ngFor=\"let week of daysGroupedByWeek;\">\n        <div class=\"day-item\" [ngClass]=\"{'day-selected': day.isSelected, 'day-disabled': !day.isEnabled}\" *ngFor=\"let day of week;\" (click)=\"selectDate(day)\">{{day.momentDate.date()}}</div>\n      </div>\n    </div>\n    <div class=\"layout-row action-container\">\n      <button ion-button class=\"cancel-button\" clear (click)=\"cancel()\">Cancel</button>\n      <button ion-button clear class=\"ok-button\" (click)=\"confirmDateSelection()\">OK</button>\n    </div>\n\n\n  </div>\n</div>",
        styles: [".date-picker .layout-row {\n  display: flex;\n  flex-direction: row; }\n\n.date-picker .layout-col {\n  display: flex;\n  flex-direction: column; }\n\n.date-picker .horizontal-center {\n  align-items: center; }\n\n.date-picker .text-center {\n  text-align: center; }\n\n.date-picker .layout-background {\n  background-color: white;\n  height: 100%; }\n\n.date-picker .padding-5 {\n  padding: 5px; }\n\n.date-picker .padding-10 {\n  padding: 10px; }\n\n.date-picker .arrow {\n  margin-left: 10px;\n  margin-right: 10px; }\n\n.date-picker .day-item-header {\n  width: 100%;\n  flex-wrap: wrap;\n  text-align: center; }\n\n.date-picker .day-item-header-item {\n  padding: 10px;\n  flex: 1;\n  font-weight: bold; }\n\n.date-picker .day-container {\n  width: 100%;\n  flex-wrap: wrap;\n  text-align: center; }\n\n.date-picker .day-item {\n  flex: 1;\n  line-height: 36px;\n  min-height: 36px; }\n\n.date-picker .day-selected {\n  background-color: #e0edff; }\n\n.date-picker .day-disabled {\n  color: #cfcfcf; }\n\n.date-picker .dayofweek {\n  font-size: 1.5em; }\n\n.date-picker .day {\n  font-size: 3em; }\n\n.date-picker .month {\n  font-size: 1.5em; }\n\n.date-picker .year {\n  font-size: 1.5em; }\n\n.date-picker .month-year {\n  font-size: 1.3em;\n  padding: 10px; }\n\n.date-picker .top-banner {\n  background-color: #1e90ff;\n  color: white;\n  width: 100%;\n  padding: 10px;\n  min-height: 200px; }\n\n.date-picker .calendar-item-container {\n  width: 100%;\n  padding: 5px;\n  min-height: 262px; }\n\n.date-picker .action-container {\n  width: 100%;\n  justify-content: Flex-end;\n  margin: 10px; }\n\n.date-picker .cancel-button {\n  color: grey; }\n"],
    }),
    __metadata("design:paramtypes", [typeof (_c = typeof ModalController !== "undefined" && ModalController) === "function" && _c || Object, typeof (_d = typeof ViewController !== "undefined" && ViewController) === "function" && _d || Object, typeof (_e = typeof NavParams !== "undefined" && NavParams) === "function" && _e || Object])
], DatePicker);
var DatePicker_1;
var _a;
var _b;
var _c;
var _d;
var _e;

var DateItem = (function () {
    function DateItem() {
    }
    return DateItem;
}());
var DatePickerOption = (function () {
    function DatePickerOption() {
    }
    return DatePickerOption;
}());

export { DatePicker, DateItem, DatePickerOption };
//# sourceMappingURL=date-picker.esm.js.map
